Class: Google::Cloud::ApiKeys::V2::Restrictions
- Inherits:
-
Object
- Object
- Google::Cloud::ApiKeys::V2::Restrictions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/api/apikeys/v2/resources.rb
Overview
Describes the restrictions on the key.
Instance Attribute Summary collapse
-
#android_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::AndroidKeyRestrictions
The Android apps that are allowed to use the key.
-
#api_targets ⇒ ::Array<::Google::Cloud::ApiKeys::V2::ApiTarget>
A restriction for a specific service and optionally one or more specific methods.
-
#browser_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::BrowserKeyRestrictions
The HTTP referrers (websites) that are allowed to use the key.
-
#ios_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::IosKeyRestrictions
The iOS apps that are allowed to use the key.
-
#server_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::ServerKeyRestrictions
The IP addresses of callers that are allowed to use the key.
Instance Attribute Details
#android_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::AndroidKeyRestrictions
Returns The Android apps that are allowed to use the key.
Note: The following fields are mutually exclusive: android_key_restrictions, browser_key_restrictions, server_key_restrictions, ios_key_restrictions. If a field in that set is populated, all other fields in the set will automatically be cleared.
113 114 115 116 |
# File 'proto_docs/google/api/apikeys/v2/resources.rb', line 113 class Restrictions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#api_targets ⇒ ::Array<::Google::Cloud::ApiKeys::V2::ApiTarget>
Returns A restriction for a specific service and optionally one or more specific methods. Requests are allowed if they match any of these restrictions. If no restrictions are specified, all targets are allowed.
113 114 115 116 |
# File 'proto_docs/google/api/apikeys/v2/resources.rb', line 113 class Restrictions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#browser_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::BrowserKeyRestrictions
Returns The HTTP referrers (websites) that are allowed to use the key.
Note: The following fields are mutually exclusive: browser_key_restrictions, server_key_restrictions, android_key_restrictions, ios_key_restrictions. If a field in that set is populated, all other fields in the set will automatically be cleared.
113 114 115 116 |
# File 'proto_docs/google/api/apikeys/v2/resources.rb', line 113 class Restrictions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ios_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::IosKeyRestrictions
Returns The iOS apps that are allowed to use the key.
Note: The following fields are mutually exclusive: ios_key_restrictions, browser_key_restrictions, server_key_restrictions, android_key_restrictions. If a field in that set is populated, all other fields in the set will automatically be cleared.
113 114 115 116 |
# File 'proto_docs/google/api/apikeys/v2/resources.rb', line 113 class Restrictions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#server_key_restrictions ⇒ ::Google::Cloud::ApiKeys::V2::ServerKeyRestrictions
Returns The IP addresses of callers that are allowed to use the key.
Note: The following fields are mutually exclusive: server_key_restrictions, browser_key_restrictions, android_key_restrictions, ios_key_restrictions. If a field in that set is populated, all other fields in the set will automatically be cleared.
113 114 115 116 |
# File 'proto_docs/google/api/apikeys/v2/resources.rb', line 113 class Restrictions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |